pub enum ConvertError {
Show 18 variants
UnsupportedSyntax {
syntax: String,
},
MissingFTemplate,
MultipleFTemplates {
count: usize,
},
MissingFTemplateName,
EmptyFTemplateName,
MissingInnerTemplate,
MultipleInnerTemplates {
count: usize,
},
UnclosedElement {
tag: String,
context: String,
},
UnclosedTag {
context: String,
},
MissingValueAttribute {
tag: String,
context: String,
},
InvalidDirectiveValue {
tag: String,
value: Option<String>,
context: String,
},
InvalidRepeatExpression {
expr: String,
context: String,
},
UnclosedBinding {
context: String,
},
EmptyBinding {
context: String,
},
UnsupportedFAttribute {
attribute: String,
context: String,
},
UnsupportedFElement {
tag: String,
context: String,
},
UnsupportedExpression {
expr: String,
reason: String,
context: String,
},
UnsupportedEventHandler {
value: String,
reason: String,
context: String,
},
}Expand description
An error encountered while converting a FAST declarative template.
Variants
UnsupportedSyntax
The requested target syntax is not supported.
MissingFTemplate
No <f-template> element was present in the input.
MultipleFTemplates
More than one <f-template> element was present in the input.
MissingFTemplateName
The <f-template> element is missing a string-valued name attribute.
EmptyFTemplateName
The <f-template name="…"> value is empty or whitespace.
MissingInnerTemplate
The <f-template> element does not contain an inner <template> element.
MultipleInnerTemplates
The <f-template> element contains more than one inner <template> element.
UnclosedElement
An HTML element was not closed.
UnclosedTag
An opening tag was not terminated with >.
MissingValueAttribute
A directive is missing its required value="{{…}}" attribute.
InvalidDirectiveValue
A directive value attribute is not wrapped in declarative binding delimiters.
InvalidRepeatExpression
An <f-repeat> expression is not in item in items form.
UnclosedBinding
A double-brace binding is not closed.
EmptyBinding
A double-brace binding has no expression.
UnsupportedFAttribute
An f-* attribute is not supported by the converter.
UnsupportedFElement
An f-* element is not supported by the converter.
UnsupportedExpression
A declarative expression is outside the supported converter grammar.
UnsupportedEventHandler
An event handler expression could not be converted.